==> haskell-heaps-0.4.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.4.1
visibility:           public
id:                   heaps-0.4.1-B8MV8G5jhysAZ5PG2dM510
key:                  heaps-0.4.1-B8MV8G5jhysAZ5PG2dM510
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  ad1c3b29f539b96be1c78bd12162062f
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-9.2.8/site-local/heaps-0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/heaps-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heaps
hs-libraries:         HSheaps-0.4.1-B8MV8G5jhysAZ5PG2dM510
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heaps-0.4-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heaps.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heaps
version:              0.4
visibility:           public
id:                   heaps-0.4-8O0EXzXBd0u214X4NFU9VO
key:                  heaps-0.4-8O0EXzXBd0u214X4NFU9VO
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  97ffa44fa7913239ec5e411c649c343b
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-8.10.5/site-local/heaps-0.4
library-dirs:         /usr/lib/ghc-8.10.5/site-local/heaps-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/heaps-0.4
hs-libraries:         HSheaps-0.4-8O0EXzXBd0u214X4NFU9VO
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
